@@ -88,8 +88,11 @@ def parse_pdf(pdf_path):
     "parse a pdf and return text string"
     reader = PdfReader(pdf_path)
     return_text = ""
-    for i in range(len(reader.pages)):
-        return_text += "[newpage] " + reader.pages[i].extract_text()
+    if any(["OceScanCompression" in key for key in reader.metadata.keys()]):
+        return_text = "[newpage] "
+    else:
+        for i in range(len(reader.pages)):
+            return_text += "[newpage] " + reader.pages[i].extract_text()
         
     return return_text
 
@@ -213,7 +216,11 @@ def convert_to_text(metadata, data_path, text_id, windows_tesseract_path = None,
             
             # update metadata file
             metadata.loc[lambda x: x.text_id == text_id, "local_txt_filepath"] = f"{data_path}txt_files/{text_id}.txt"
-            metadata.loc[lambda x: x.text_id == text_id, "detected_language"] = detect(return_text)
+            try:
+                detected_lang = detect(return_text)
+            except:
+                detected_lang = "en"
+            metadata.loc[lambda x: x.text_id == text_id, "detected_language"] = detected_lang
             final_return = metadata
         else:
             final_return = None
